@@ -107,17 +107,6 @@ func NewAppConfig(
 		return nil, err
 	}
 
-	// Temporary: the defaults for these are set to empty strings in
-	// getDefaultAppState so that we can migrate them from userConfig (which is
-	// now deprecated). Once we remove the user configs, we can remove this code
-	// and set the proper defaults in getDefaultAppState.
-	if appState.GitLogOrder == "" {
-		appState.GitLogOrder = userConfig.Git.Log.Order
-	}
-	if appState.GitLogShowGraph == "" {
-		appState.GitLogShowGraph = userConfig.Git.Log.ShowGraph
-	}
-
 	appConfig := &AppConfig{
 		name:                  name,
 		version:               version,
@@ -136,7 +125,7 @@ func NewAppConfig(
 }
 
 func ConfigDir() string {
-	_, filePath := findConfigFile("config.yml")
+	_, filePath := findConfigFile(ConfigFilename)
 
 	return filepath.Dir(filePath)
 }
@@ -288,7 +277,7 @@ func computeMigratedConfig(path string, content []byte, changes *ChangesSet) ([]
 	for _, pathToReplace := range pathsToReplace {
 		err, didReplace := yaml_utils.RenameYamlKey(&rootNode, pathToReplace.oldPath, pathToReplace.newName)
 		if err != nil {
-			return nil, false, fmt.Errorf("Couldn't migrate config file at `%s` for key %s: %s", path, strings.Join(pathToReplace.oldPath, "."), err)
+			return nil, false, fmt.Errorf("Couldn't migrate config file at `%s` for key %s: %w", path, strings.Join(pathToReplace.oldPath, "."), err)
 		}
 		if didReplace {
 			changes.Add(fmt.Sprintf("Renamed '%s' to '%s'", strings.Join(pathToReplace.oldPath, "."), pathToReplace.newName))
@@ -297,27 +286,27 @@ func computeMigratedConfig(path string, content []byte, changes *ChangesSet) ([]
 
 	err = changeNullKeybindingsToDisabled(&rootNode, changes)
 	if err != nil {
-		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %s", path, err)
+		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %w", path, err)
 	}
 
 	err = changeElementToSequence(&rootNode, []string{"git", "commitPrefix"}, changes)
 	if err != nil {
-		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %s", path, err)
+		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %w", path, err)
 	}
 
 	err = changeCommitPrefixesMap(&rootNode, changes)
 	if err != nil {
-		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %s", path, err)
+		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %w", path, err)
 	}
 
 	err = changeCustomCommandStreamAndOutputToOutputEnum(&rootNode, changes)
 	if err != nil {
-		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %s", path, err)
+		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %w", path, err)
 	}
 
 	err = migrateAllBranchesLogCmd(&rootNode, changes)
 	if err != nil {
-		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %s", path, err)
+		return nil, false, fmt.Errorf("Couldn't migrate config file at `%s`: %w", path, err)
 	}
 
 	// Add more migrations here...
@@ -667,45 +656,21 @@ func (c *AppConfig) SaveGlobalUserConfig() {
 // AppState stores data between runs of the app like when the last update check
 // was performed and which other repos have been checked out
 type AppState struct {
-	LastUpdateCheck     int64
-	RecentRepos         []string
-	StartupPopupVersion int
-	LastVersion         string // this is the last version the user was using, for the purpose of showing release notes
+	LastUpdateCheck        int64
+	RecentRepos            []string
+	StartupPopupVersion    int
+	DidShowHunkStagingHint bool
+	LastVersion            string // this is the last version the user was using, for the purpose of showing release notes
 
 	// these are for shell commands typed in directly, not for custom commands in the lazygit config.
 	// For backwards compatibility we keep the old name in yaml files.
 	ShellCommandsHistory []string `yaml:"customcommandshistory"`
 
-	HideCommandLog             bool
-	IgnoreWhitespaceInDiffView bool
-	DiffContextSize            uint64
-	RenameSimilarityThreshold  int
-	LocalBranchSortOrder       string
-	RemoteBranchSortOrder      string
-
-	// One of: 'date-order' | 'author-date-order' | 'topo-order' | 'default'
-	// 'topo-order' makes it easier to read the git log graph, but commits may not
-	// appear chronologically. See https://git-scm.com/docs/
-	GitLogOrder string
-
-	// This determines whether the git graph is rendered in the commits panel
-	// One of 'always' | 'never' | 'when-maximised'
-	GitLogShowGraph string
+	HideCommandLog bool
 }
 
 func getDefaultAppState() *AppState {
-	return &AppState{
-		LastUpdateCheck:           0,
-		RecentRepos:               []string{},
-		StartupPopupVersion:       0,
-		LastVersion:               "",
-		DiffContextSize:           3,
-		RenameSimilarityThreshold: 50,
-		LocalBranchSortOrder:      "recency",
-		RemoteBranchSortOrder:     "alphabetical",
-		GitLogOrder:               "", // should be "topo-order" eventually
-		GitLogShowGraph:           "", // should be "always" eventually
-	}
+	return &AppState{}
 }
 
 func LogPath() (string, error) {
