@@ -316,10 +316,10 @@ type PagingConfig struct {
 	// delta --dark --paging=never
 	// ydiff -p cat -s --wrap --width={{columnWidth}}
 	Pager PagerType `yaml:"pager"`
-	// If true, Lazygit will use whatever pager is specified in `$GIT_PAGER`, `$PAGER`, or your *git config*. If the pager ends with something like ` | less` we will strip that part out, because less doesn't play nice with our rendering approach. If the custom pager uses less under the hood, that will also break rendering (hence the `--paging=never` flag for the `delta` pager).
-	UseConfig bool `yaml:"useConfig"`
 	// e.g. 'difft --color=always'
 	ExternalDiffCommand string `yaml:"externalDiffCommand"`
+	// If true, Lazygit will use git's `diff.external` config for paging. The advantage over `externalDiffCommand` is that this can be configured per file type in .gitattributes; see https://git-scm.com/docs/gitattributes#_defining_an_external_diff_driver.
+	UseExternalDiffGitConfig bool `yaml:"useExternalDiffGitConfig"`
 }
 
 type CommitConfig struct {
@@ -390,6 +390,7 @@ type KeybindingConfig struct {
 type KeybindingUniversalConfig struct {
 	Quit                              string   `yaml:"quit"`
 	QuitAlt1                          string   `yaml:"quit-alt1"`
+	SuspendApp                        string   `yaml:"suspendApp"`
 	Return                            string   `yaml:"return"`
 	QuitWithoutChangingDirectory      string   `yaml:"quitWithoutChangingDirectory"`
 	TogglePanel                       string   `yaml:"togglePanel"`
@@ -424,6 +425,8 @@ type KeybindingUniversalConfig struct {
 	Select                            string   `yaml:"select"`
 	GoInto                            string   `yaml:"goInto"`
 	Confirm                           string   `yaml:"confirm"`
+	ConfirmMenu                       string   `yaml:"confirmMenu"`
+	ConfirmSuggestion                 string   `yaml:"confirmSuggestion"`
 	ConfirmInEditor                   string   `yaml:"confirmInEditor"`
 	ConfirmInEditorAlt                string   `yaml:"confirmInEditor-alt"`
 	Remove                            string   `yaml:"remove"`
@@ -796,7 +799,6 @@ func GetDefaultConfig() *UserConfig {
 			Paging: PagingConfig{
 				ColorArg:            "always",
 				Pager:               "",
-				UseConfig:           false,
 				ExternalDiffCommand: "",
 			},
 			Commit: CommitConfig{
@@ -854,6 +856,7 @@ func GetDefaultConfig() *UserConfig {
 			Universal: KeybindingUniversalConfig{
 				Quit:                              "q",
 				QuitAlt1:                          "<c-c>",
+				SuspendApp:                        "<c-z>",
 				Return:                            "<esc>",
 				QuitWithoutChangingDirectory:      "Q",
 				TogglePanel:                       "<tab>",
@@ -888,6 +891,8 @@ func GetDefaultConfig() *UserConfig {
 				Select:                            "<space>",
 				GoInto:                            "<enter>",
 				Confirm:                           "<enter>",
+				ConfirmMenu:                       "<enter>",
+				ConfirmSuggestion:                 "<enter>",
 				ConfirmInEditor:                   "<a-enter>",
 				ConfirmInEditorAlt:                "<c-s>",
 				Remove:                            "d",
@@ -912,7 +917,7 @@ func GetDefaultConfig() *UserConfig {
 				NextScreenMode:                    "+",
 				PrevScreenMode:                    "_",
 				Undo:                              "z",
-				Redo:                              "<c-z>",
+				Redo:                              "Z",
 				FilteringMenu:                     "<c-s>",
 				DiffingMenu:                       "W",
 				DiffingMenuAlt:                    "<c-e>",
