@@ -35,11 +35,12 @@ func (self *GlobalController) GetKeybindings(opts types.KeybindingsOpts) []*type
 			OpensMenu:   true,
 		},
 		{
-			Key:         opts.GetKey(opts.Config.Universal.CreateRebaseOptionsMenu),
-			Handler:     opts.Guards.NoPopupPanel(self.c.Helpers().MergeAndRebase.CreateRebaseOptionsMenu),
-			Description: self.c.Tr.ViewMergeRebaseOptions,
-			Tooltip:     self.c.Tr.ViewMergeRebaseOptionsTooltip,
-			OpensMenu:   true,
+			Key:               opts.GetKey(opts.Config.Universal.CreateRebaseOptionsMenu),
+			Handler:           opts.Guards.NoPopupPanel(self.c.Helpers().MergeAndRebase.CreateRebaseOptionsMenu),
+			Description:       self.c.Tr.ViewMergeRebaseOptions,
+			Tooltip:           self.c.Tr.ViewMergeRebaseOptionsTooltip,
+			OpensMenu:         true,
+			GetDisabledReason: self.canShowRebaseOptions,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.Refresh),
@@ -57,6 +58,15 @@ func (self *GlobalController) GetKeybindings(opts types.KeybindingsOpts) []*type
 			Handler:     opts.Guards.NoPopupPanel(self.prevScreenMode),
 			Description: self.c.Tr.PrevScreenMode,
 		},
+		{
+			Key:               opts.GetKey(opts.Config.Universal.Return),
+			Modifier:          gocui.ModNone,
+			Handler:           self.escape,
+			Description:       self.c.Tr.Cancel,
+			DescriptionFunc:   self.escapeDescription,
+			GetDisabledReason: self.escapeEnabled,
+			DisplayOnScreen:   true,
+		},
 		{
 			ViewName:  "",
 			Key:       opts.GetKey(opts.Config.Universal.OptionMenu),
@@ -114,11 +124,18 @@ func (self *GlobalController) GetKeybindings(opts types.KeybindingsOpts) []*type
 			Handler:  self.quitWithoutChangingDirectory,
 		},
 		{
-			Key:             opts.GetKey(opts.Config.Universal.Return),
-			Modifier:        gocui.ModNone,
-			Handler:         self.escape,
-			Description:     self.c.Tr.Cancel,
-			DisplayOnScreen: true,
+			Key:         opts.GetKey(opts.Config.Universal.SuspendApp),
+			Modifier:    gocui.ModNone,
+			Handler:     self.c.Helpers().SuspendResume.SuspendApp,
+			Description: self.c.Tr.SuspendApp,
+			GetDisabledReason: func() *types.DisabledReason {
+				if !self.c.Helpers().SuspendResume.CanSuspendApp() {
+					return &types.DisabledReason{
+						Text: self.c.Tr.CannotSuspendApp,
+					}
+				}
+				return nil
+			},
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.ToggleWhitespaceInDiffView),
@@ -142,7 +159,8 @@ func (self *GlobalController) createCustomPatchOptionsMenu() error {
 }
 
 func (self *GlobalController) refresh() error {
-	return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+	self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+	return nil
 }
 
 func (self *GlobalController) nextScreenMode() error {
@@ -188,6 +206,29 @@ func (self *GlobalController) escape() error {
 	return (&QuitActions{c: self.c}).Escape()
 }
 
+func (self *GlobalController) escapeDescription() string {
+	return (&QuitActions{c: self.c}).EscapeDescription()
+}
+
+func (self *GlobalController) escapeEnabled() *types.DisabledReason {
+	if (&QuitActions{c: self.c}).EscapeEnabled() {
+		return nil
+	}
+
+	// The empty error text is intentional. We don't want to show an error
+	// toast for this, but only hide it from the options map.
+	return &types.DisabledReason{Text: ""}
+}
+
 func (self *GlobalController) toggleWhitespace() error {
 	return (&ToggleWhitespaceAction{c: self.c}).Call()
 }
+
+func (self *GlobalController) canShowRebaseOptions() *types.DisabledReason {
+	if self.c.Model().WorkingTreeStateAtLastCommitRefresh.None() {
+		return &types.DisabledReason{
+			Text: self.c.Tr.NotMergingOrRebasing,
+		}
+	}
+	return nil
+}
