@@ -47,9 +47,10 @@ func (self *BranchesHelper) ConfirmLocalDelete(branches []*models.Branch) error
 			if err := self.c.Git().Branch.LocalDelete(branchNames, true); err != nil {
 				return err
 			}
-			selectionStart, _ := self.c.Contexts().Branches.GetSelectionRange()
-			self.c.Contexts().Branches.SetSelectedLineIdx(selectionStart)
-			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES}})
+
+			self.c.Contexts().Branches.CollapseRangeSelectionToTop()
+			self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES}})
+			return nil
 		})
 	}
 
@@ -81,7 +82,7 @@ func (self *BranchesHelper) ConfirmLocalDelete(branches []*models.Branch) error
 	return nil
 }
 
-func (self *BranchesHelper) ConfirmDeleteRemote(remoteBranches []*models.RemoteBranch) error {
+func (self *BranchesHelper) ConfirmDeleteRemote(remoteBranches []*models.RemoteBranch, resetRemoteBranchesSelection bool) error {
 	var title string
 	if len(remoteBranches) == 1 {
 		title = utils.ResolvePlaceholderString(
@@ -113,7 +114,11 @@ func (self *BranchesHelper) ConfirmDeleteRemote(remoteBranches []*models.RemoteB
 				if err := self.deleteRemoteBranches(remoteBranches, task); err != nil {
 					return err
 				}
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES, types.REMOTES}})
+				self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES, types.REMOTES}})
+				if resetRemoteBranchesSelection {
+					self.c.Contexts().RemoteBranches.CollapseRangeSelectionToTop()
+				}
+				return nil
 			})
 		},
 	})
@@ -178,10 +183,9 @@ func (self *BranchesHelper) ConfirmLocalAndRemoteDelete(branches []*models.Branc
 					return err
 				}
 
-				selectionStart, _ := self.c.Contexts().Branches.GetSelectionRange()
-				self.c.Contexts().Branches.SetSelectedLineIdx(selectionStart)
-
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES, types.REMOTES}})
+				self.c.Contexts().Branches.CollapseRangeSelectionToTop()
+				self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES, types.REMOTES}})
+				return nil
 			})
 		},
 	})
@@ -279,7 +283,9 @@ func (self *BranchesHelper) AutoForwardBranches() error {
 	updateCommands := ""
 	// The first branch is the currently checked out branch; skip it
 	for _, branch := range branches[1:] {
-		if branch.RemoteBranchStoredLocally() && (allBranches || lo.Contains(self.c.UserConfig().Git.MainBranches, branch.Name)) {
+		if branch.RemoteBranchStoredLocally() &&
+			!self.checkedOutByOtherWorktree(branch) &&
+			(allBranches || lo.Contains(self.c.UserConfig().Git.MainBranches, branch.Name)) {
 			isStrictlyBehind := branch.IsBehindForPull() && !branch.IsAheadForPull()
 			if isStrictlyBehind {
 				updateCommands += fmt.Sprintf("update %s %s %s\n", branch.FullRefName(), branch.FullUpstreamRefName(), branch.CommitHash)
@@ -295,7 +301,7 @@ func (self *BranchesHelper) AutoForwardBranches() error {
 	self.c.LogCommand(strings.TrimRight(updateCommands, "\n"), false)
 	err := self.c.Git().Branch.UpdateBranchRefs(updateCommands)
 
-	_ = self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.BRANCHES}, Mode: types.SYNC})
+	self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.BRANCHES}, Mode: types.SYNC})
 
 	return err
 }
