@@ -2,6 +2,7 @@ package helpers
 
 import (
 	"fmt"
+	"math"
 	"strings"
 
 	"github.com/jesseduffield/lazycore/pkg/boxlayout"
@@ -78,10 +79,10 @@ func (self *WindowArrangementHelper) GetWindowDimensions(informationStr string,
 	repoState := self.c.State().GetRepoState()
 
 	var searchPrefix string
-	if repoState.GetSearchState().SearchType() == types.SearchTypeSearch {
-		searchPrefix = self.c.Tr.SearchPrefix
+	if filterableContext, ok := repoState.GetSearchState().Context.(types.IFilterableContext); ok {
+		searchPrefix = filterableContext.FilterPrefix(self.c.Tr)
 	} else {
-		searchPrefix = self.c.Tr.FilterPrefix
+		searchPrefix = self.c.Tr.SearchPrefix
 	}
 
 	args := WindowArrangementArgs{
@@ -237,14 +238,14 @@ func mainSectionChildren(args WindowArrangementArgs) []*boxlayout.Box {
 }
 
 func getMidSectionWeights(args WindowArrangementArgs) (int, int) {
-	// we originally specified this as a ratio i.e. .20 would correspond to a weight of 1 against 4
 	sidePanelWidthRatio := args.UserConfig.Gui.SidePanelWidth
-	// we could make this better by creating ratios like 2:3 rather than always 1:something
-	mainSectionWeight := int(1/sidePanelWidthRatio) - 1
-	sideSectionWeight := 1
+	// Using 120 so that the default of 0.3333 will remain consistent with previous behavior
+	const maxColumnCount = 120
+	mainSectionWeight := int(math.Round(maxColumnCount * (1 - sidePanelWidthRatio)))
+	sideSectionWeight := int(math.Round(maxColumnCount * sidePanelWidthRatio))
 
 	if splitMainPanelSideBySide(args) {
-		mainSectionWeight = 5 // need to shrink side panel to make way for main panels if side-by-side
+		mainSectionWeight = sideSectionWeight * 5 // need to shrink side panel to make way for main panels if side-by-side
 	}
 
 	if args.CurrentWindow == "main" || args.CurrentWindow == "secondary" {
@@ -254,9 +255,9 @@ func getMidSectionWeights(args WindowArrangementArgs) (int, int) {
 	} else {
 		if args.ScreenMode == types.SCREEN_HALF {
 			if args.UserConfig.Gui.EnlargedSideViewLocation == "top" {
-				mainSectionWeight = 2
+				mainSectionWeight = sideSectionWeight * 2
 			} else {
-				mainSectionWeight = 1
+				mainSectionWeight = sideSectionWeight
 			}
 		} else if args.ScreenMode == types.SCREEN_FULL {
 			mainSectionWeight = 0
@@ -384,9 +385,8 @@ func splitMainPanelSideBySide(args WindowArrangementArgs) bool {
 	default:
 		if args.Width < 200 && args.Height > 30 { // 2 80 character width panels + 40 width for side panel
 			return false
-		} else {
-			return true
 		}
+		return true
 	}
 }
 
@@ -430,11 +430,11 @@ func sidePanelChildren(args WindowArrangementArgs) func(width int, height int) [
 						Window: window,
 						Weight: 1,
 					}
-				} else {
-					return &boxlayout.Box{
-						Window: window,
-						Size:   0,
-					}
+				}
+
+				return &boxlayout.Box{
+					Window: window,
+					Size:   0,
 				}
 			}
 
@@ -468,33 +468,33 @@ func sidePanelChildren(args WindowArrangementArgs) func(width int, height int) [
 				accordionBox(&boxlayout.Box{Window: "commits", Weight: 1}),
 				accordionBox(getDefaultStashWindowBox(args)),
 			}
-		} else {
-			squashedHeight := 1
-			if height >= 21 {
-				squashedHeight = 3
-			}
+		}
 
-			squashedSidePanelBox := func(window string) *boxlayout.Box {
-				if window == args.CurrentSideWindow {
-					return &boxlayout.Box{
-						Window: window,
-						Weight: 1,
-					}
-				} else {
-					return &boxlayout.Box{
-						Window: window,
-						Size:   squashedHeight,
-					}
+		squashedHeight := 1
+		if height >= 21 {
+			squashedHeight = 3
+		}
+
+		squashedSidePanelBox := func(window string) *boxlayout.Box {
+			if window == args.CurrentSideWindow {
+				return &boxlayout.Box{
+					Window: window,
+					Weight: 1,
 				}
 			}
 
-			return []*boxlayout.Box{
-				squashedSidePanelBox("status"),
-				squashedSidePanelBox("files"),
-				squashedSidePanelBox("branches"),
-				squashedSidePanelBox("commits"),
-				squashedSidePanelBox("stash"),
+			return &boxlayout.Box{
+				Window: window,
+				Size:   squashedHeight,
 			}
 		}
+
+		return []*boxlayout.Box{
+			squashedSidePanelBox("status"),
+			squashedSidePanelBox("files"),
+			squashedSidePanelBox("branches"),
+			squashedSidePanelBox("commits"),
+			squashedSidePanelBox("stash"),
+		}
 	}
 }
