@@ -1,10 +1,9 @@
 //go:build !windows
-// +build !windows
 
 package clients
 
 // This file allows you to use `go test` to run integration tests.
-// See See pkg/integration/README.md for more info.
+// See pkg/integration/README.md for more info.
 
 import (
 	"bytes"
@@ -45,12 +44,6 @@ func TestIntegration(t *testing.T) {
 				return
 			}
 
-			// not running demoes right now. Arguably we should, but we'd need to
-			// strip away any artificial lag they use.
-			if test.IsDemo() {
-				return
-			}
-
 			t.Run(test.Name(), func(t *testing.T) {
 				t.Parallel()
 				err := f()
